@@ -138,7 +138,9 @@ func Run(opts *Options, version string, revision string) {
 			opts.Fuzzy, opts.FuzzyAlgo, opts.Extended, opts.Case, opts.Normalize, forward, withPos,
 			opts.Filter == nil, opts.Nth, opts.Delimiter, runes)
 	}
-	matcher := NewMatcher(patternBuilder, sort, opts.Tac, eventBox)
+	inputRevision := 0
+	snapshotRevision := 0
+	matcher := NewMatcher(patternBuilder, sort, opts.Tac, eventBox, inputRevision)
 
 	// Filtering mode
 	if opts.Filter != nil {
@@ -209,25 +211,15 @@ func Run(opts *Options, version string, revision string) {
 
 	// Event coordination
 	reading := true
-	clearCache := util.Once(false)
-	clearSelection := util.Once(false)
 	ticks := 0
 	var nextCommand *string
-	restart := func(command string) {
-		reading = true
-		clearCache = util.Once(true)
-		clearSelection = util.Once(true)
-		chunkList.Clear()
-		itemIndex = 0
-		header = make([]string, 0, opts.HeaderLines)
-		go reader.restart(command)
-	}
 	eventBox.Watch(EvtReadNew)
 	total := 0
 	query := []rune{}
 	determine := func(final bool) {
 		if heightUnknown {
 			if total >= maxFit || final {
+				deferred = false
 				heightUnknown = false
 				terminal.startChan <- fitpad{util.Min(total, maxFit), padHeight}
 			}
@@ -236,10 +228,23 @@ func Run(opts *Options, version string, revision string) {
 			terminal.startChan <- fitpad{-1, -1}
 		}
 	}
+
+	useSnapshot := false
+	var snapshot []*Chunk
+	var count int
+	restart := func(command string) {
+		reading = true
+		chunkList.Clear()
+		itemIndex = 0
+		inputRevision++
+		header = make([]string, 0, opts.HeaderLines)
+		go reader.restart(command)
+	}
 	for {
 		delay := true
 		ticks++
-		input := func(reloaded bool) []rune {
+		input := func() []rune {
+			reloaded := snapshotRevision != inputRevision
 			paused, input := terminal.Input()
 			if reloaded && paused {
 				query = []rune{}
@@ -267,25 +272,35 @@ func Run(opts *Options, version string, revision string) {
 					} else {
 						reading = reading && evt == EvtReadNew
 					}
-					snapshot, count := chunkList.Snapshot()
+					if useSnapshot && evt == EvtReadFin {
+						useSnapshot = false
+					}
+					if !useSnapshot {
+						snapshot, count = chunkList.Snapshot()
+						snapshotRevision = inputRevision
+					}
 					total = count
 					terminal.UpdateCount(total, !reading, value.(*string))
 					if opts.Sync {
 						opts.Sync = false
-						terminal.UpdateList(PassMerger(&snapshot, opts.Tac), false)
+						terminal.UpdateList(PassMerger(&snapshot, opts.Tac, snapshotRevision))
 					}
 					if heightUnknown && !deferred {
 						determine(!reading)
 					}
-					reset := clearCache()
-					matcher.Reset(snapshot, input(reset), false, !reading, sort, reset)
+					matcher.Reset(snapshot, input(), false, !reading, sort, snapshotRevision)
 
 				case EvtSearchNew:
 					var command *string
+					var changed bool
 					switch val := value.(type) {
 					case searchRequest:
 						sort = val.sort
 						command = val.command
+						changed = val.changed
+						if command != nil {
+							useSnapshot = val.sync
+						}
 					}
 					if command != nil {
 						if reading {
@@ -294,11 +309,20 @@ func Run(opts *Options, version string, revision string) {
 						} else {
 							restart(*command)
 						}
+					}
+					if !changed {
 						break
 					}
-					snapshot, _ := chunkList.Snapshot()
-					reset := clearCache()
-					matcher.Reset(snapshot, input(reset), true, !reading, sort, reset)
+					if !useSnapshot {
+						newSnapshot, _ := chunkList.Snapshot()
+						// We want to avoid showing empty list when reload is triggered
+						// and the query string is changed at the same time i.e. command != nil && changed
+						if command == nil || len(newSnapshot) > 0 {
+							snapshot = newSnapshot
+							snapshotRevision = inputRevision
+						}
+					}
+					matcher.Reset(snapshot, input(), true, !reading, sort, snapshotRevision)
 					delay = false
 
 				case EvtSearchProgress:
@@ -338,7 +362,7 @@ func Run(opts *Options, version string, revision string) {
 								determine(val.final)
 							}
 						}
-						terminal.UpdateList(val, clearSelection())
+						terminal.UpdateList(val)
 					}
 				}
 			}
